pub enum Commands {
Show 28 variants
Delete {Show 16 fields
file: PathBuf,
symbol: String,
kind: Option<SymbolKind>,
analyzer: Option<AnalyzerMode>,
analyzer_binary: Option<PathBuf>,
language: Option<Language>,
context_after: usize,
context_before: usize,
context: usize,
create_backup: bool,
relationships: bool,
dry_run: bool,
unified: usize,
operation_id: Option<String>,
metadata: Option<String>,
snapshot_before: bool,
},
Patch {Show 20 fields
file: Option<PathBuf>,
symbol: Option<String>,
kind: Option<SymbolKind>,
analyzer: Option<AnalyzerMode>,
analyzer_binary: Option<PathBuf>,
with_: Option<PathBuf>,
language: Option<Language>,
batch: Option<PathBuf>,
context_after: usize,
context_before: usize,
context_both: usize,
preview: bool,
unified: usize,
create_backup: bool,
relationships: bool,
operation_id: Option<String>,
metadata: Option<String>,
db: Option<PathBuf>,
snapshot_before: bool,
impact_graph: bool,
},
Plan {
file: PathBuf,
operation_id: Option<String>,
metadata: Option<String>,
},
Undo {
manifest: PathBuf,
},
ApplyFiles {
glob: String,
find: String,
replace: String,
language: Option<Language>,
context_after: usize,
context_before: usize,
context_both: usize,
no_validate: bool,
create_backup: bool,
operation_id: Option<String>,
metadata: Option<String>,
dry_run: bool,
},
Query {
db: PathBuf,
label: Vec<String>,
file: Option<String>,
context_after: usize,
context_before: usize,
context_both: usize,
list: bool,
count: bool,
show_code: bool,
relationships: bool,
expand: bool,
expand_level: usize,
},
Get {
db: PathBuf,
file: PathBuf,
start: usize,
end: usize,
context_after: usize,
context_before: usize,
context_both: usize,
relationships: bool,
expand: bool,
expand_level: usize,
},
Log {
operation_type: Option<String>,
status: Option<String>,
after: Option<String>,
before: Option<String>,
limit: usize,
offset: usize,
execution_id: Option<String>,
json: bool,
stats: bool,
},
Explain {
code: String,
},
Search {
pattern: String,
path: PathBuf,
language: Option<Language>,
glob: Option<String>,
context_after: usize,
context_before: usize,
context_both: usize,
apply: bool,
replace: Option<String>,
json: bool,
},
Status {
db: PathBuf,
detect_backend: bool,
},
Find {
db: PathBuf,
name: Option<String>,
symbol_id: Option<String>,
ambiguous: bool,
output: OutputFormat,
},
Refs {
db: PathBuf,
name: String,
path: PathBuf,
direction: CallDirection,
output: OutputFormat,
impact_graph: bool,
},
Files {
db: PathBuf,
symbols: bool,
output: OutputFormat,
},
Export {
db: PathBuf,
format: ExportFormat,
file: Option<PathBuf>,
},
MigrateDb {
db_path: PathBuf,
backup: bool,
dry_run: bool,
},
Rename {
symbol: Option<String>,
name: Option<String>,
file: Option<PathBuf>,
to: String,
db: PathBuf,
preview: bool,
proof: bool,
backup_dir: Option<PathBuf>,
no_backup: bool,
create_backup: bool,
snapshot_before: bool,
impact_graph: bool,
},
Reachable {
symbol: String,
path: PathBuf,
db: PathBuf,
direction: ReachabilityDirection,
max_depth: usize,
output: OutputFormat,
impact_graph: bool,
},
DeadCode {
entry: String,
path: PathBuf,
db: PathBuf,
exclude_public: bool,
group_by_file: bool,
output: OutputFormat,
},
Cycles {
db: PathBuf,
symbol: Option<String>,
path: Option<PathBuf>,
max_cycles: usize,
show_members: bool,
output: OutputFormat,
},
Condense {
db: PathBuf,
show_members: bool,
show_levels: bool,
output: OutputFormat,
},
Slice {
target: String,
path: PathBuf,
db: PathBuf,
direction: SliceDirection,
max_depth: Option<usize>,
output: OutputFormat,
},
ValidateProof {
proof: PathBuf,
output: OutputFormat,
},
Verify {
before: PathBuf,
after: PathBuf,
detailed: bool,
output: OutputFormat,
},
Batch {
spec: PathBuf,
db: Option<PathBuf>,
dry_run: bool,
continue_on_error: bool,
rollback: CliRollbackMode,
analyzer: Option<AnalyzerMode>,
analyzer_binary: Option<PathBuf>,
},
Create {
file: PathBuf,
validate_only: bool,
with_mod: bool,
workspace: PathBuf,
},
Complete {
file: PathBuf,
line: usize,
column: usize,
max_results: usize,
db: PathBuf,
},
Snapshots(SnapshotsCommands),
}Expand description
Available Splice commands.
Variants
Delete
Delete a symbol by removing its definition.
Fields
kind: Option<SymbolKind>Optional symbol kind filter.
analyzer: Option<AnalyzerMode>Optional validation mode (off, os, path).
Patch
Apply a patch to a symbol’s span.
Fields
kind: Option<SymbolKind>Optional symbol kind filter.
analyzer: Option<AnalyzerMode>Optional validation mode (off, os, path).
Plan
Execute a multi-step refactoring plan.
Fields
Undo
Undo a previous operation by restoring from a backup manifest.
ApplyFiles
Apply a pattern replacement to multiple files.
Fields
Query
Query symbols by labels (uses Magellan integration).
Fields
label: Vec<String>Labels to query (can be specified multiple times). Examples: rust, python, fn, struct, class, method, etc.
Get
Get code chunks from the database (uses Magellan integration).
Fields
Log
Query execution log.
Fields
Explain
Explain an error code with detailed documentation.
Search
Search for code patterns in files.
Fields
Status
Show database statistics (files, symbols, refs, calls, chunks)
Use –detect-backend to check which backend format the database uses.
Fields
Find
Find symbols by name or 16-character symbol ID
Fields
output: OutputFormatOutput format (human, json, pretty)
Refs
Show call relationships for a symbol
Fields
direction: CallDirectionDirection: in (callers), out (callees), both (default)
output: OutputFormatOutput format (human, json, pretty)
Files
List all indexed files
Fields
output: OutputFormatOutput format (human, json, pretty)
Export
Export graph data in JSON, JSONL, or CSV format
Fields
format: ExportFormatExport format (json, jsonl, csv)
MigrateDb
Migrate Magellan database to latest schema version
Fields
Rename
Rename a symbol across all files using byte-accurate references
Fields
Reachable
Show reachability analysis for a symbol (caller/callee chains)
Fields
direction: ReachabilityDirectionAnalysis direction: forward (callees), reverse (callers), both
output: OutputFormatOutput format (human, json, pretty)
DeadCode
Detect dead code (unreachable symbols) from entry points
Fields
output: OutputFormatOutput format (human, json, pretty)
Cycles
Detect cycles in the call graph
Fields
output: OutputFormatOutput format (human, json, pretty)
Condense
Analyze condensation graph (SCCs collapsed to DAG)
Fields
output: OutputFormatOutput format (human, json, pretty)
Slice
Perform program slicing (forward/backward impact analysis)
Fields
direction: SliceDirectionSlice direction: forward (what this affects) or backward (what affects this)
output: OutputFormatOutput format (human, json, pretty)
ValidateProof
Validate proof checksums for refactoring audit trail
Fields
output: OutputFormatOutput format (human, json, pretty)
Verify
Compare two snapshots and report differences
Fields
output: OutputFormatOutput format (human, json, pretty)
Batch
Execute batch operations from YAML spec
Fields
rollback: CliRollbackModeRollback mode: auto, never, always
analyzer: Option<AnalyzerMode>Optional validation mode (off, os, path).
Create
Create a new file with validation
Fields
Complete
Get grounded code completions using Magellan database
Fields
Snapshots(SnapshotsCommands)
Manage code graph snapshots